@@ -592,7 +592,7 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		if (!email.isEmpty())
 			page->kURLRequester1->setUrl(QString(revurl + email.section(QLatin1Char( '@' ), 0, 0) + QLatin1String( ".revoke" )));
 		else
-			page->kURLRequester1->setUrl(QString(revurl + email.section(QLatin1Char( ' ' ), 0, 0) + QLatin1String( ".revoke" )));
+			page->kURLRequester1->setUrl(QString(revurl + genkey->getName().section(QLatin1Char(' '), 0, 0) + QLatin1String(".revoke")));
 
 		const QString fingerprint(genkey->getFingerprint());
 		page->TLid->setText(QLatin1String( "<b>" ) + fingerprint.right(8) + QLatin1String( "</b>" ));
@@ -602,11 +602,8 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		keyCreated->setMainWidget(page);
 
 		keyCreated->exec();
-		if (keyCreated.isNull()) {
+		if (keyCreated.isNull())
 			return;
-		} else {
-			delete keyCreated;
-		}
 
 		imodel->refreshKey(fingerprint);
 		KGpgKeyNode *knode = imodel->getRootNode()->findKey(fingerprint);
@@ -630,6 +627,7 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 
 			genRev->start();
 		}
+		delete keyCreated;
 		break;
 	}
 	default:
